{% import 'keg_elements/forms/horizontal.html' as horizontal %}
{% extends 'keg_auth/form-base.html' %}

{% block form %}
{{
    horizontal.form(form, action_text=submit_button_text,
                    cancel_url=auth_manager.url_for('login'))
}}
{% endblock %}
